/* This file was generated by syncqt. */
#ifndef QT_QT3DRENDER_VERSION_H
#define QT_QT3DRENDER_VERSION_H

#define QT3DRENDER_VERSION_STR "5.9.7"

#define QT3DRENDER_VERSION 0x050907

#endif // QT_QT3DRENDER_VERSION_H
