/* This file was generated by syncqt. */
#ifndef QT_QTPURCHASING_VERSION_H
#define QT_QTPURCHASING_VERSION_H

#define QTPURCHASING_VERSION_STR "5.9.7"

#define QTPURCHASING_VERSION 0x050907

#endif // QT_QTPURCHASING_VERSION_H
